var group__DRV__HSMCLIENT__MODULE =
[
    [ "HsmVer_t", "unionHsmVer__t__.html", [
      [ "HsmrtVer", "unionHsmVer__t__.html#a8c5ddfe5a8c5a319511da15173f1bddf", null ],
      [ "PatchVer", "unionHsmVer__t__.html#a70bf9470061405797b50c2eeabd5ece9", null ],
      [ "MinorVer", "unionHsmVer__t__.html#ad55db97e96e0ac15e76a3d3c00926ca9", null ],
      [ "MajorVer", "unionHsmVer__t__.html#abacc37f3e50532a8708bf412554ca804", null ],
      [ "ApiVer", "unionHsmVer__t__.html#ae12b2b1eae53f975b4c5aa7f70083c4e", null ],
      [ "SocType", "unionHsmVer__t__.html#a80966ed6e43b6a71770caefd3e74bfe8", null ],
      [ "BinType", "unionHsmVer__t__.html#a5039d70022111e461514910fb8b7bf6d", null ],
      [ "HsmType", "unionHsmVer__t__.html#aa7e996a7803b829378ea7efccadac977", null ],
      [ "DevType", "unionHsmVer__t__.html#a9a7b1394576ad37f11c06c5238904c80", null ],
      [ "VerStruct", "unionHsmVer__t__.html#a81a5aaa38306e8f696c6c8b0ffad1e32", null ]
    ] ],
    [ "HsmClient_t", "structHsmClient__t.html", [
      [ "Semaphore", "structHsmClient__t.html#a7cd9b04785e82bb2cee46684529ed624", null ],
      [ "ReqMsg", "structHsmClient__t.html#a6c8b2b402da89b78a5eb2c55eb8b36ef", null ],
      [ "RespMsg", "structHsmClient__t.html#ad1d591cabaa37b805d043bbc96b76efe", null ],
      [ "RespFlag", "structHsmClient__t.html#aca5698f283bb2661ff38e9350d973278", null ],
      [ "ClientId", "structHsmClient__t.html#ae827a9b61005b18ad00ff52186663ec0", null ]
    ] ],
    [ "NvmOtpRead_t", "structNvmOtpRead__t.html", [
      [ "rowData", "structNvmOtpRead__t.html#a571eb786ba88a2d052c831bac3f5bcd9", null ],
      [ "rowIdx", "structNvmOtpRead__t.html#a2a95199e7ce2f4a3dc0e1c4e6bd10e00", null ],
      [ "rsvd", "structNvmOtpRead__t.html#a353803d37077762c61e623b50b789ab1", null ]
    ] ],
    [ "NvmOtpRowWrite_t", "structNvmOtpRowWrite__t.html", [
      [ "rowData", "structNvmOtpRowWrite__t.html#aa9235b996bd0e62cf8747898d8e2e32d", null ],
      [ "rowBitMask", "structNvmOtpRowWrite__t.html#a48a28ba607d5da273a433ec353dfd6d1", null ],
      [ "rowIdx", "structNvmOtpRowWrite__t.html#acc2d3fdf546814e4a6eb21834a430872", null ],
      [ "rsvd", "structNvmOtpRowWrite__t.html#a9fead7996007ae34ef4b63f212fd9728", null ]
    ] ],
    [ "NvmOtpRowCount_t", "structNvmOtpRowCount__t.html", [
      [ "rowCount", "structNvmOtpRowCount__t.html#a8119948c52eecdc11c7309ba8d0fcb55", null ],
      [ "rowSize", "structNvmOtpRowCount__t.html#a5b8fbe952a36f539af19e9538623bc0d", null ],
      [ "rsvd", "structNvmOtpRowCount__t.html#a984bfff2d473d11a02b346e71e9f6260", null ]
    ] ],
    [ "NvmOtpRowProt_t", "structNvmOtpRowProt__t.html", [
      [ "rowidx", "structNvmOtpRowProt__t.html#a53d250b1fc167e82203155255613ca74", null ],
      [ "readProt", "structNvmOtpRowProt__t.html#a7c5a7992c5966cc1c9d8fd86556783d9", null ],
      [ "writeProt", "structNvmOtpRowProt__t.html#a715daa763ddb8c86296ebfa89737599b", null ]
    ] ],
    [ "KeyWriterCertHeader_t", "structKeyWriterCertHeader__t.html", [
      [ "certAddress", "structKeyWriterCertHeader__t.html#ae9b90a224e0f7a5529d517f530dbe9bc", null ],
      [ "certSize", "structKeyWriterCertHeader__t.html#a893d8b73710ca98a4b909a9d3e2a7080", null ],
      [ "debugResponse", "structKeyWriterCertHeader__t.html#ad37e915b946b5134b281ecba21c5fc17", null ],
      [ "reserved", "structKeyWriterCertHeader__t.html#ad863397eca11dd14aea46409009e23aa", null ]
    ] ],
    [ "FirewallRegionReq_t", "structFirewallRegionReq__t.html", [
      [ "firewallId", "structFirewallRegionReq__t.html#abc11df4b0af4c8174587fc3e27cbaa84", null ],
      [ "region", "structFirewallRegionReq__t.html#afeeff1bd5891d1826ef4ae47514fbb12", null ],
      [ "permissionAttributes", "structFirewallRegionReq__t.html#a48772bfc7d8b5ea9d62cb5146a86e18a", null ],
      [ "startAddress", "structFirewallRegionReq__t.html#a7b548afc2de395afea9c79227610b36a", null ],
      [ "endAddress", "structFirewallRegionReq__t.html#ac9c2cc8dbc241cf6f99608d0d47483d4", null ]
    ] ],
    [ "FirewallReq_t", "structFirewallReq__t.html", [
      [ "regionCount", "structFirewallReq__t.html#a517b37cdf25d7cd61b2ffe644f15df59", null ],
      [ "crcArr", "structFirewallReq__t.html#a13f059b3ce67788bae334a186eacf743", null ],
      [ "FirewallRegionArr", "structFirewallReq__t.html#ad46aa5f2946a3cc035a64aff66d37878", null ],
      [ "statusFirewallRegionArr", "structFirewallReq__t.html#a9c9804e0edbc604ad4b77937429092dc", null ]
    ] ],
    [ "FirewallIntrReq_t", "structFirewallIntrReq__t.html", [
      [ "firewallId", "structFirewallIntrReq__t.html#abd0ff8cb914f32f07e8d8769691754b3", null ],
      [ "interruptEnable", "structFirewallIntrReq__t.html#acf477d8e7189537db3350332c7f95917", null ],
      [ "interruptEnableClear", "structFirewallIntrReq__t.html#ad931a180ebba4369b293985f9462ea11", null ],
      [ "interruptEnableStatusClear", "structFirewallIntrReq__t.html#ae010c0d59ea37104743b1eba04df8f45", null ],
      [ "faultClear", "structFirewallIntrReq__t.html#aed7702b1f519dbbae14464b4db614c22", null ]
    ] ],
    [ "SWRev_t", "structSWRev__t.html", [
      [ "revValue", "structSWRev__t.html#acf11f341e179eaf10c1b49755bd95596", null ],
      [ "revId", "structSWRev__t.html#ad55c6dae84716e240bec8508a4d2d1ef", null ],
      [ "rsvd", "structSWRev__t.html#a8bbfe7caf80f97c32d821fd904ea6f9d", null ]
    ] ],
    [ "DKEK_t", "structDKEK__t.html", [
      [ "label_length", "structDKEK__t.html#a30de202c06efff2554915e26652c2ce4", null ],
      [ "context_length", "structDKEK__t.html#a9f93e29528c06e196b89d8504fd951dd", null ],
      [ "label_and_context", "structDKEK__t.html#adda720e2f4fd9279d1cbe97226448717", null ],
      [ "dkek", "structDKEK__t.html#a848520beb1d787bde9cd8248eadc7f5a", null ]
    ] ],
    [ "RNGReq_t", "structRNGReq__t.html", [
      [ "resultPtr", "structRNGReq__t.html#a7f11dbcce3865cf9f6e646e59041fbce", null ],
      [ "resultLength", "structRNGReq__t.html#ad438f724500da363130732f3fa4f9547", null ],
      [ "DRBGMode", "structRNGReq__t.html#a1cf5e08f42274763be462b1d809809b0", null ],
      [ "seedValue", "structRNGReq__t.html#acc02eaa30b2ec21c4dbbe53be162f83f", null ],
      [ "seedSizeInDWords", "structRNGReq__t.html#af2d671abd0d683afe5510529f4c17852", null ],
      [ "reserved", "structRNGReq__t.html#ab353fe43175f1a59afd66e070e26ccf7", null ]
    ] ],
    [ "SecureBoot_Stream_t_", "structSecureBoot__Stream__t__.html", [
      [ "dataIn", "structSecureBoot__Stream__t__.html#a697d619037c57b00c45b2a00dad9c085", null ],
      [ "dataLen", "structSecureBoot__Stream__t__.html#aafdf72f0ffb5c674ce10d71421b8a442", null ],
      [ "canBeEncrypted", "structSecureBoot__Stream__t__.html#ac57e013865793f6e709c538fbfff0e9b", null ]
    ] ],
    [ "FirmwareUpdateReq_t", "structFirmwareUpdateReq__t.html", [
      [ "pStartAddress", "structFirmwareUpdateReq__t.html#a463a78b6ea9280aa15131fbc264a0bc6", null ],
      [ "dataLength", "structFirmwareUpdateReq__t.html#a1e35264b745dbd898621ac266168e101", null ],
      [ "pDecryptionBuffer", "structFirmwareUpdateReq__t.html#a75b8d4e2369d40662df06e5e5bbab31e", null ],
      [ "decryptionBufferLength", "structFirmwareUpdateReq__t.html#a9a8459ba4181862ec8b706e8548adfbd", null ]
    ] ],
    [ "OTFA_Region_t", "structOTFA__Region__t.html", [
      [ "authMode", "structOTFA__Region__t.html#a236b3066e5cde785b75cf16ad3b7455c", null ],
      [ "encMode", "structOTFA__Region__t.html#a1435efd6cd94f12f15ab7abd82d5f6b1", null ],
      [ "reservedArea", "structOTFA__Region__t.html#ae6c243b1ea673231a1b8d9cd3521e410", null ],
      [ "regionStAddr", "structOTFA__Region__t.html#ae914583d5d1205e1321af285377606ad", null ],
      [ "regionSize", "structOTFA__Region__t.html#a8d6ffb1fbb7f52f5032522729474d0ca", null ],
      [ "authKeyID", "structOTFA__Region__t.html#ac7ff83d7afd98fdb743dda899850b126", null ],
      [ "encrKeyID", "structOTFA__Region__t.html#ac421959f3c07dde1bfd0dc27887961fa", null ],
      [ "encrKeyFetchMode", "structOTFA__Region__t.html#aa4d71b5db9af35fc8fdf5623d6cbe064", null ],
      [ "authAesKey", "structOTFA__Region__t.html#a1c5d1c86503c7f6a134d5b141ea9b2c9", null ],
      [ "encrAesKey", "structOTFA__Region__t.html#a7cdd18580fb63bba643053b27ff7e276", null ],
      [ "regionIV", "structOTFA__Region__t.html#a4fb86253339968bc95bece68df15903a", null ]
    ] ],
    [ "OTFA_readRegion_t", "structOTFA__readRegion__t.html", [
      [ "regionNumber", "structOTFA__readRegion__t.html#a9dec6bef5a644ca08d5749f07783150c", null ],
      [ "authMode", "structOTFA__readRegion__t.html#a5c1192a6b2c9ef5c02d9769a021bb20e", null ],
      [ "encMode", "structOTFA__readRegion__t.html#a8cbb6fffd6fd74732439da5405b9cd52", null ],
      [ "authKeyHash", "structOTFA__readRegion__t.html#a9d96af01f19f729a7003945c44a32a54", null ],
      [ "encKeyHash", "structOTFA__readRegion__t.html#ad329051e95175f465497f2b687f772ca", null ],
      [ "regionStAddr", "structOTFA__readRegion__t.html#a18f23ccdc1ca0fb33eda6667ee23425f", null ],
      [ "regionSize", "structOTFA__readRegion__t.html#ae674ff28d6e5c20d6cc2d5a32c4b5c58", null ],
      [ "regionIV", "structOTFA__readRegion__t.html#aa9fd572011ce72c62e9b9c55f515f3ec", null ]
    ] ],
    [ "OTFA_Config_t", "structOTFA__Config__t.html", [
      [ "OTFA_Reg", "structOTFA__Config__t.html#af0af656c74b9d1d3eb6c5243c9421efc", null ],
      [ "numRegions", "structOTFA__Config__t.html#ac57d9ff49cbb848e026bf4a518dcd262", null ],
      [ "keySize", "structOTFA__Config__t.html#aae9b1fe56ace4712160ea79238b203a3", null ],
      [ "macSize", "structOTFA__Config__t.html#a523e667f9c6cef57b463c68a74b5239c", null ],
      [ "masterEnable", "structOTFA__Config__t.html#a278cf42eedc223b75bc24988de8242d2", null ]
    ] ],
    [ "SecCfgValidate_t", "structSecCfgValidate__t.html", [
      [ "pCertAddress", "structSecCfgValidate__t.html#acb212f3bd732a18680c9e60b59ed9e6d", null ],
      [ "certType", "structSecCfgValidate__t.html#ac9dc63cccab6188cf94dfeea596dadf0", null ]
    ] ],
    [ "FlashBankCopy_t", "structFlashBankCopy__t.html", [
      [ "cpuFlashBankType", "structFlashBankCopy__t.html#ad1220dd6b3216f69921bff5b11ed4a74", null ]
    ] ],
    [ "HsmMsg_t_", "structHsmMsg__t__.html", [
      [ "destClientId", "structHsmMsg__t__.html#af7693475522e1a00bad5144d3369373e", null ],
      [ "srcClientId", "structHsmMsg__t__.html#aa2fad9ffe66fecc74ef1ec07402e7993", null ],
      [ "flags", "structHsmMsg__t__.html#afc969e502c188ef74cb93453aaeb9abb", null ],
      [ "serType", "structHsmMsg__t__.html#a836dcc1345a86466ada579d730ca7968", null ],
      [ "args", "structHsmMsg__t__.html#aad6ee90325db4533ad5deb87783e088a", null ],
      [ "crcArgs", "structHsmMsg__t__.html#a93ce9171f1f16578a49889494a51b9a0", null ],
      [ "crcMsg", "structHsmMsg__t__.html#a3991bf21542bf41141ca53488830a87c", null ]
    ] ],
    [ "LABEL_AND_CONTEXT_LEN_MAX", "group__DRV__HSMCLIENT__MODULE.html#ga2cbcf82afe6a7d15348511aba221038e", null ],
    [ "HSMRT_LOAD_NOT_REQUESTED", "group__DRV__HSMCLIENT__MODULE.html#gae70b88f1db290b0e6c2a39af4b08bac5", null ],
    [ "HSMRT_LOAD_REQUESTED", "group__DRV__HSMCLIENT__MODULE.html#ga638efa23dd93c2e8e4363f18346bef8d", null ],
    [ "HSMRT_LOAD_FAILED", "group__DRV__HSMCLIENT__MODULE.html#ga92d3271387e20dd0d7a19a1b75fd03a3", null ],
    [ "HSMRT_LOAD_SUCCEEDED", "group__DRV__HSMCLIENT__MODULE.html#gad45cb0a88284e85531b0d6d19cd2ef7a", null ],
    [ "HSM_MSG_GET_VERSION", "group__DRV__HSMCLIENT__MODULE.html#gadf3a90c05d8c1565e696412e009e54d5", null ],
    [ "HSM_MSG_BOOT_NOTIFY", "group__DRV__HSMCLIENT__MODULE.html#ga65e1efbec7ecc3f8a2c27e8a26b9ead0", null ],
    [ "HSM_MSG_GET_UID", "group__DRV__HSMCLIENT__MODULE.html#gac0b1702fe87b12cc7f14360f25b1886d", null ],
    [ "HSM_MSG_OPEN_DBG_FIREWALLS", "group__DRV__HSMCLIENT__MODULE.html#ga9f8b9d794ea45b3b84c8444ac55a6a92", null ],
    [ "HSM_MSG_READ_OTP_ROW", "group__DRV__HSMCLIENT__MODULE.html#ga284c1488f234b5606461d997e1369b7f", null ],
    [ "HSM_MSG_WRITE_OTP_ROW", "group__DRV__HSMCLIENT__MODULE.html#ga13b3c4c751956ade310d8557d658069a", null ],
    [ "HSM_MSG_PROT_OTP_ROW", "group__DRV__HSMCLIENT__MODULE.html#gafe17db2ae4f7c34e7becf025bdba047b", null ],
    [ "HSM_MSG_GET_OTP_ROW_PROT", "group__DRV__HSMCLIENT__MODULE.html#ga4d3098d04746f48a0e13ea43d7bbee07", null ],
    [ "HSM_MSG_GET_OTP_ROW_COUNT", "group__DRV__HSMCLIENT__MODULE.html#ga20f64b7d732c4398f02a7b1f31ce6942", null ],
    [ "HSM_MSG_PROC_AUTH_BOOT", "group__DRV__HSMCLIENT__MODULE.html#ga086e64f083c375a6a544ecb897a5e808", null ],
    [ "HSM_MSG_PROC_AUTH_BOOT_START", "group__DRV__HSMCLIENT__MODULE.html#gaf3e78ff4ee13ec3291d2a6ca113c6ebf", null ],
    [ "HSM_MSG_PROC_AUTH_BOOT_UPDATE", "group__DRV__HSMCLIENT__MODULE.html#ga8be85db0335c86f43199079ca1a7bd56", null ],
    [ "HSM_MSG_PROC_AUTH_BOOT_FINISH", "group__DRV__HSMCLIENT__MODULE.html#gade0ff1220e7784fa3bb3cdd4a66d3bac", null ],
    [ "HSM_MSG_SET_FIREWALL", "group__DRV__HSMCLIENT__MODULE.html#ga92d7f4ed104f2993d6f4fc5e3ab64b16", null ],
    [ "HSM_MSG_SET_FIREWALL_INTR", "group__DRV__HSMCLIENT__MODULE.html#ga6ace22f3d1a8aa74e87a099bc0c8fe5f", null ],
    [ "HSM_KEYWRITER_SEND_CUST_KEY_CERT", "group__DRV__HSMCLIENT__MODULE.html#ga03acf9305bed1bd5f6274d68654fbebf", null ],
    [ "HSM_MSG_READ_SWREV", "group__DRV__HSMCLIENT__MODULE.html#ga3128d82dbf482b300e9c4d9130a48a67", null ],
    [ "HSM_MSG_WRITE_SWREV", "group__DRV__HSMCLIENT__MODULE.html#gab851495b31ea6c655a595cb7c37ee1e0", null ],
    [ "HSM_MSG_GET_DKEK", "group__DRV__HSMCLIENT__MODULE.html#gae651f78369da8b101485b6fc0a7abe60", null ],
    [ "HSM_MSG_GET_RAND", "group__DRV__HSMCLIENT__MODULE.html#gaf05a0c5e56858508f64e34077b8715be", null ],
    [ "HSM_MSG_KEYRING_IMPORT", "group__DRV__HSMCLIENT__MODULE.html#ga97b39c4cb2a0b51752457314b0e7b0db", null ],
    [ "HSM_MSG_FW_UPDATE_CERT_PROCESS", "group__DRV__HSMCLIENT__MODULE.html#ga2e90671f1c2eab08c262f9c8f6a3c0b2", null ],
    [ "HSM_MSG_FW_UPDATE_CODE_PROGRAM", "group__DRV__HSMCLIENT__MODULE.html#ga6fc0516fd1fd7d27371ed347c0cd4793", null ],
    [ "HSM_MSG_FW_UPDATE_CODE_VERIFY", "group__DRV__HSMCLIENT__MODULE.html#gaf4083171109dd06124c9e017cd3b48e7", null ],
    [ "HSM_MSG_VERIFY_ROT_CERT", "group__DRV__HSMCLIENT__MODULE.html#gab744690a05eb6b161e2e12cdb5e1e624", null ],
    [ "HSM_MSG_UPDATE_KEY_REV", "group__DRV__HSMCLIENT__MODULE.html#ga084b34edef554076dbfb4b91ee88ccad", null ],
    [ "HSM_MSG_CONFIGURE_OTFA", "group__DRV__HSMCLIENT__MODULE.html#ga8a621825ddd676ee8ad7a2a365d91c75", null ],
    [ "HSM_MSG_READ_OTFA", "group__DRV__HSMCLIENT__MODULE.html#ga23d267eaff2aca3dc800e6944ff9b1dd", null ],
    [ "HSM_MSG_PROC_AUTH_BOOT_SEC_CFG", "group__DRV__HSMCLIENT__MODULE.html#gaab5435a13c609f9d255749ea551375a7", null ],
    [ "HSM_MSG_FLASH_BANK_COPY", "group__DRV__HSMCLIENT__MODULE.html#ga9b9e4251d86003eb35eadb0f9712430a", null ],
    [ "HSM_FLAG_AOP", "group__DRV__HSMCLIENT__MODULE.html#ga0842e3d812796be34207849e8dc8dc3a", null ],
    [ "HSM_FLAG_NAOP", "group__DRV__HSMCLIENT__MODULE.html#ga5f0c48b13ab8d657a61ff359466f16e8", null ],
    [ "HSM_FLAG_ACK", "group__DRV__HSMCLIENT__MODULE.html#gae54cfaab6d2e23b938c84ac9979ad5c3", null ],
    [ "HSM_FLAG_NACK", "group__DRV__HSMCLIENT__MODULE.html#ga731ec3b9b7da7d175314ada557260e72", null ],
    [ "HSM_CLIENT_ID", "group__DRV__HSMCLIENT__MODULE.html#gad6503e342107d57430fa7621bf791f52", null ],
    [ "HSM_UID_SIZE", "group__DRV__HSMCLIENT__MODULE.html#gaaeb1c6f595adbdc6376975787d729ebf", null ],
    [ "HSM_DBG_CERT_SIZE", "group__DRV__HSMCLIENT__MODULE.html#ga7a8b28618350bb63e5ee3a0e00046e7d", null ],
    [ "HSM_KEYRING_CERT_SIZE", "group__DRV__HSMCLIENT__MODULE.html#ga0d9cee170bb254076dd1547c080a1f2a", null ],
    [ "HSM_FIRMWARE_CHUNK_SIZE", "group__DRV__HSMCLIENT__MODULE.html#ga203d7a4701a305f2886cda8e50d8de34", null ],
    [ "CERT_TYPE_SECCFG_CPU1", "group__DRV__HSMCLIENT__MODULE.html#gadd307f3415afa4c105cc6834393bd4cf", null ],
    [ "CERT_TYPE_SECCFG_CPU2", "group__DRV__HSMCLIENT__MODULE.html#gad536c0b1371f2e33a655d8c8b985bb3f", null ],
    [ "CERT_TYPE_SECCFG_CPU3", "group__DRV__HSMCLIENT__MODULE.html#gafd5dcb2bc8278823739e5593ed356060", null ],
    [ "C29_CPU1_FLASH_BANK", "group__DRV__HSMCLIENT__MODULE.html#ga259589a714501cf1e41c76ae13d044f2", null ],
    [ "C29_CPU3_FLASH_BANK", "group__DRV__HSMCLIENT__MODULE.html#ga71049731bfb2c2f920ef1285adb5ed38", null ],
    [ "HSM_CPU_FLASH_BANK", "group__DRV__HSMCLIENT__MODULE.html#gacb03d811f9790f24a66ae050489c45bf", null ],
    [ "HSM_ClientIds_t", "group__DRV__HSMCLIENT__MODULE.html#gaf92e5f18d6f413cb32cb051ca6216668", [
      [ "HSM_BOOT_NOTIFY_CLIENT_ID", "group__DRV__HSMCLIENT__MODULE.html#ggaf92e5f18d6f413cb32cb051ca6216668a79284f0eb3363ea9a70583e47c3c158c", null ],
      [ "HSM_CLIENT_ID_1", "group__DRV__HSMCLIENT__MODULE.html#ggaf92e5f18d6f413cb32cb051ca6216668a48bc5244479e5f3282525436fe825ab9", null ],
      [ "HSM_CLIENT_ID_2", "group__DRV__HSMCLIENT__MODULE.html#ggaf92e5f18d6f413cb32cb051ca6216668a8659b9f9f58b2fd2cddf8e108b0abdd4", null ],
      [ "HSM_CLIENT_ID_3", "group__DRV__HSMCLIENT__MODULE.html#ggaf92e5f18d6f413cb32cb051ca6216668ac89aed5c53cf7a5d4eae3fa8e865ef59", null ],
      [ "HSM_CLIENT_ID_4", "group__DRV__HSMCLIENT__MODULE.html#ggaf92e5f18d6f413cb32cb051ca6216668a255ee4008bd22e3bb06751b16e97fefa", null ]
    ] ],
    [ "__attribute__", "group__DRV__HSMCLIENT__MODULE.html#ga28e9d652ffab5e6671a4316837302fe8", null ],
    [ "HsmClient_checkAndWaitForBootNotification", "group__DRV__HSMCLIENT__MODULE.html#gadf502ebd6e67f563777ec1345822cdb3", null ],
    [ "HsmClient_init", "group__DRV__HSMCLIENT__MODULE.html#ga3b55ad3229c657ca509f9b29451e37e5", null ],
    [ "HsmClient_deInit", "group__DRV__HSMCLIENT__MODULE.html#gae44cff19b801c9299bac8eaaea14c88d", null ],
    [ "HsmClient_SecureBootQueueInit", "group__DRV__HSMCLIENT__MODULE.html#ga56b1b7c7c3aa0dbc595b196c63520357", null ],
    [ "HsmClient_getVersion", "group__DRV__HSMCLIENT__MODULE.html#ga70b2b53821f5782e083984e34df972b7", null ],
    [ "HsmClient_getUID", "group__DRV__HSMCLIENT__MODULE.html#gad9f5c4c23d11b16ef7ff0eb03a7fa740", null ],
    [ "HsmClient_openDbgFirewall", "group__DRV__HSMCLIENT__MODULE.html#ga3746ff39aab53e9aa4ed690a7dd33b15", null ],
    [ "HsmClient_importKeyring", "group__DRV__HSMCLIENT__MODULE.html#ga44bd1d6da427b7614a34969d2ef5ec17", null ],
    [ "HsmClient_readOTPRow", "group__DRV__HSMCLIENT__MODULE.html#gace3361fd0f3fc438e9b7e0a1acfe2122", null ],
    [ "HsmClient_writeOTPRow", "group__DRV__HSMCLIENT__MODULE.html#ga96f53cf958e70929245d0f21e10f038e", null ],
    [ "HsmClient_lockOTPRow", "group__DRV__HSMCLIENT__MODULE.html#gab43e961650612c91157c0587b3d2746f", null ],
    [ "HsmClient_getOTPRowCount", "group__DRV__HSMCLIENT__MODULE.html#gae625624727a8de14944f65d25fececd5", null ],
    [ "HsmClient_getOTPRowProtection", "group__DRV__HSMCLIENT__MODULE.html#gaca8f5f005b283ec144d9e178b12388ca", null ],
    [ "HsmClient_procAuthBoot", "group__DRV__HSMCLIENT__MODULE.html#ga210471c61013f15ddf77447071a5b0c2", null ],
    [ "HsmClient_procAuthBootStart", "group__DRV__HSMCLIENT__MODULE.html#gaf7d1b7f1f395db8af308fc8bfc723262", null ],
    [ "HsmClient_procAuthBootUpdate", "group__DRV__HSMCLIENT__MODULE.html#gaf2f86243a283d118581e6aadfbfc1a38", null ],
    [ "HsmClient_procAuthBootFinish", "group__DRV__HSMCLIENT__MODULE.html#ga9d63686b1b160cd528b53c19c7514640", null ],
    [ "HsmClient_setFirewall", "group__DRV__HSMCLIENT__MODULE.html#ga823fa989f0c2b87f8b231da6f4000e12", null ],
    [ "HsmClient_FirewallIntr", "group__DRV__HSMCLIENT__MODULE.html#ga421bbbfc557a3dbfd8e807a1e569fd65", null ],
    [ "HsmClient_keyWriter", "group__DRV__HSMCLIENT__MODULE.html#ga71bef66d729437b542a5178e1bf24a11", null ],
    [ "HsmClient_readSWRev", "group__DRV__HSMCLIENT__MODULE.html#gaa04564fc8949545d87b1058f4e9b42df", null ],
    [ "HsmClient_writeSWRev", "group__DRV__HSMCLIENT__MODULE.html#ga6cb697a7edc9ed0cda9e18cf4c9fcb01", null ],
    [ "HsmClient_getDKEK", "group__DRV__HSMCLIENT__MODULE.html#ga167cf5d7571ab15f4350e744c9e88ed1", null ],
    [ "HsmClient_register", "group__DRV__HSMCLIENT__MODULE.html#ga152f4adbca2128ca988769beca7009aa", null ],
    [ "HsmClient_unregister", "group__DRV__HSMCLIENT__MODULE.html#ga2d712c43bc058c71d3c1134a3b2501c5", null ],
    [ "HsmClient_waitForBootNotify", "group__DRV__HSMCLIENT__MODULE.html#gaead2ef4c3b6ee91e2a0a8789fa33e79a", null ],
    [ "Hsmclient_loadHSMRtFirmware", "group__DRV__HSMCLIENT__MODULE.html#ga3c42304858235375f45a90e887c67f9e", null ],
    [ "Hsmclient_loadHSMRtFirmwareNonBlocking", "group__DRV__HSMCLIENT__MODULE.html#gaf7c0556aeb71dcb34f153e40f08082fe", null ],
    [ "HsmClient_getRandomNum", "group__DRV__HSMCLIENT__MODULE.html#ga8748595521349c269558061b568f3acd", null ],
    [ "HsmClient_firmwareUpdate_CertProcess", "group__DRV__HSMCLIENT__MODULE.html#ga7e11bffb33e2a74e2380ebc3161a33e9", null ],
    [ "HsmClient_firmwareUpdate_CodeProgram", "group__DRV__HSMCLIENT__MODULE.html#ga5dcdae29f13a16b7d685d945f6fcb42a", null ],
    [ "HsmClient_firmwareUpdate_CodeVerify", "group__DRV__HSMCLIENT__MODULE.html#ga607526aad2aa236e8227e9c0f20fcd5c", null ],
    [ "HsmClient_VerifyROTSwitchingCertificate", "group__DRV__HSMCLIENT__MODULE.html#ga1ffcf953c8b05aabe050f14f0919fd23", null ],
    [ "HsmClient_UpdateKeyRevsion", "group__DRV__HSMCLIENT__MODULE.html#ga530b1603d591126ac346c31f30414f7d", null ],
    [ "HsmClient_configOTFARegions", "group__DRV__HSMCLIENT__MODULE.html#ga5ea570bc441bb6c6a9dff879b0600e27", null ],
    [ "HsmClient_readOTFARegions", "group__DRV__HSMCLIENT__MODULE.html#gae655894963d794110ea5de532102ef64", null ],
    [ "HsmClient_secCfgValidate", "group__DRV__HSMCLIENT__MODULE.html#ga6634bc2f8d0d9f5574111f6070838002", null ],
    [ "HsmClient_activeToDormantBankCopy", "group__DRV__HSMCLIENT__MODULE.html#ga2a4fabce99d63a311aab8352a9fe890b", null ]
];